<?php
/**
 * @package     Joomla.Administrator
 * @copyright   Copyright (C) 2013 IPrice web solutions. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

defined('_JEXEC') or die;

jimport('joomla.application.component.modellist');

class IpricecalcModelItems extends JModelList
{
	public function __construct($config = array())
	{
		if (empty($config['filter_fields'])) 
		{
			//THIS ARRAY IS IMPORTANT FOR SORTING
			$config['filter_fields'] = array(
				'name', 'state', 'category_id' 
			);
		}

		parent::__construct($config);
	}

	/**
	 * Build an SQL query to load the list data.
	 *
	 * @return	JDatabaseQuery
	 * @since	1.6
	 */
	protected function getListQuery()
	{
	
		$db		= $this->getDbo();
		$query	= $db->getQuery(true);

		// Select the required fields from the table.
		$query->select(
			$this->getState(
				'list.select',
				'ipi.*'
			)
		);
		$query->from($db->quoteName('#__iprice_item').' AS ipi');
		
		// Join over the categories.
		$query->select('ipc.name AS category');
		$query->join('LEFT', '#__iprice_categories AS ipc ON ipc.id = ipi.catid');
		

		// Filter by published state
		$published = $this->getState('filter.state');
		if (is_numeric($published)) {
			$query->where('ipi.published = '.(int) $published);
		}
		
		$catid = (int) $this->getState('filter.category_id');
		if ($catid)
			$query->where('ipi.catid = '.$catid);

		$search = $this->getState('filter.search');
		if (!empty($search)) {
			if (stripos($search, 'id:') === 0) {
				$query->where('ipi.id = '.(int) substr($search, 3));
			} else {
				$search = $db->Quote('%'.$db->escape($search, true).'%');
				$query->where('(ipi.name LIKE '.$search.' OR ipi.shortdesc LIKE '.$search.')');
			}
		}

		$orderCol	= $this->state->get('list.ordering', 'ipc.ordering,ipi.ordering');
		$orderDirn	= $this->state->get('list.direction', 'ASC');
		$query->order($db->escape($orderCol.' '.$orderDirn));

		return $query;
	}

	protected function getStoreId($id = '')
	{
		// Compile the store id.
		$id	.= ':'.$this->getState('filter.search');
		$id	.= ':'.$this->getState('filter.state');
		$id	.= ':'.$this->getState('filter.category_id');

		return parent::getStoreId($id);
	}

	public function getTable($type = 'Item', $prefix = 'IpricecalcTable', $config = array())
	{
		return JTable::getInstance($type, $prefix, $config);
	}

	protected function populateState($ordering = null, $direction = NULL)
	{
		$app = JFactory::getApplication('administrator');

		// Load the filter state.
		$search = $this->getUserStateFromRequest($this->context.'.filter.search', 'filter_search');
		$this->setState('filter.search', $search);

		$state = $this->getUserStateFromRequest($this->context.'.filter.state', 'filter_state', '', 'string');
		$this->setState('filter.state', $state);
		
		$catid = $this->getUserStateFromRequest($this->context.'.filter.category_id', 'filter_category_id', '', 'string');
		$this->setState('filter.category_id', $catid);
		

		// Load the parameters.
		$params = JComponentHelper::getParams('com_ipricecalc');
		$this->setState('params', $params);

		// List state information.
		parent::populateState('ipc.ordering,ipi.ordering', 'ASC');
	}
}
?>