<?php
/**
 * @package     Joomla.Administrator
 * @copyright   Copyright (C) 2013 IPrice web solutions. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

defined('_JEXEC') or die;

jimport('joomla.application.component.modellist');

class IpricecalcModelOrders extends JModelList
{
	public function __construct($config = array())
	{
		if (empty($config['filter_fields'])) {
			$config['filter_fields'] = array( 'ipo.orderno', 
				'ipo.orderdate', 'ipo.fio', 'ipo.firm', 'ipo.email', 'ipo.grandtotal', 'ipo.id','datefrom','dateto' );
		}
		parent::__construct($config);
	}

	/**
	 * Build an SQL query to load the list data.
	 *
	 * @return	JDatabaseQuery
	 * @since	1.6
	 */
	protected function getListQuery()
	{
	
		$db		= $this->getDbo();
		$query	= $db->getQuery(true);

		// Select the required fields from the table.
		$query->select(
			$this->getState(
				'list.select',
				'ipo.*'
			)
		);
		$query->from($db->quoteName('#__iprice_order_main').' AS ipo');
		
		$datefrom = $this->getState('filter.datefrom');
		if ($datefrom)
		{
			try { $datefrom = new JDate($datefrom);	}
			catch (Exception $ex) { $datefrom = NULL; }
			if ($datefrom)
			{
				$datefrom = $db->Quote($datefrom->format('Y-m-d',false,false));
				$query->where('ipo.orderdate>='.$datefrom);
			}
				
		}
		$dateto = $this->getState('filter.dateto');
		if ($dateto)
		{
			try { $dateto = new JDate($dateto);	}
			catch (Exception $ex) { $dateto = NULL; }
			if ($dateto)
			{
				$dateto = $db->Quote($dateto->format('Y-m-d',false,false));
				$query->where('ipo.orderdate<='.$dateto);
			}
		}
	
		$search = $this->getState('filter.search');
		if (!empty($search)) {
			if (stripos($search, 'id:') === 0) {
				$query->where('ipo.id = '.(int) substr($search, 3));
			} else {
				$search = $db->Quote('%'.$db->escape($search, true).'%');
				$query->where('(ipo.orderno LIKE '.$search.' OR ipo.email LIKE '.$search.' OR ipo.fio LIKE '.$search.' OR ipo.firm LIKE '.$search .') ');
			}
		}
		$orderCol	= $this->state->get('list.ordering', 'ipo.orderno');
		$orderDirn	= $this->state->get('list.direction', 'DESC');
		$query->order($db->escape($orderCol.' '.$orderDirn));
		
		return $query;
	}

	protected function getStoreId($id = '')
	{
		// Compile the store id.
		$id	.= ':'.$this->getState('filter.search');
		$id	.= ':'.$this->getState('filter.datefrom');
		$id	.= ':'.$this->getState('filter.dateto');
		$id	.= ':'.$this->getState('filter.state');

		return parent::getStoreId($id);
	}

	public function getTable($type = 'Order', $prefix = 'IpricecalcTable', $config = array())
	{
		return JTable::getInstance($type, $prefix, $config);
	}

	protected function populateState($ordering = null, $direction = null)
	{
		$app = JFactory::getApplication('administrator');

		$datefrom = $this->getUserStateFromRequest($this->context.'.filter.datefrom', 'filter_datefrom');
		$this->setState('filter.datefrom', $datefrom);

		$dateto = $this->getUserStateFromRequest($this->context.'.filter.dateto', 'filter_dateto');
		$this->setState('filter.dateto', $dateto);
		
		// Load the filter state.
		$search = $this->getUserStateFromRequest($this->context.'.filter.search', 'filter_search');
		$this->setState('filter.search', $search);

		$state = $this->getUserStateFromRequest($this->context.'.filter.state', 'filter_state', '', 'string');
		$this->setState('filter.state', $state);

		// Load the parameters.
		$params = JComponentHelper::getParams('com_ipricecalc');
		$this->setState('params', $params);

		// List state information.
		parent::populateState($ordering, $direction);
	}
}
?>